##  Prerequisites
  * Activate the AI agent extension to the meta model. This extension adds the needed entities to your workspace. To learn more, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  * Upload AI agents to SAP LeanIX using AI agent discovery. Without AI agent fact sheets, relevant content doesn’t appear on the dashboard. For detailed information, see [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Discover AI agents and MCP servers by setting up integrations with agent-building platforms and registry systems. Review discovered items in the AI agent discovery inbox and add relevant ones to your inventory.").
